# ✨ Introduction

Ragas is a library that provides tools to supercharge the evaluation of Large Language Model (LLM) applications. It is designed to help you evaluate your LLM applications with ease and confidence. 



<div class="grid cards" markdown>
- 🚀 **Get Started**

    Install with `pip` and get started with Ragas with these tutorials.

    [:octicons-arrow-right-24: Get Started](getstarted/index.md)

- 📚 **Core Concepts**

    In depth explanation and discussion of the concepts and working of different features available in Ragas.

    [:octicons-arrow-right-24: Core Concepts](concepts/index.md)

- 🛠️ **How-to Guides**

    Practical guides to help you achieve a specific goals. Take a look at these
    guides to learn how to use Ragas to solve real-world problems.

    [:octicons-arrow-right-24: How-to Guides](howtos/index.md)

- 📖 **References**

    Technical descriptions of how Ragas classes and methods work.

    [:octicons-arrow-right-24: References](references/index.md)

</div>